General open and methods (sarpy.io.product.converter)
=====================================================

.. automodule:: sarpy.io.product.converter
    :members:
    :show-inheritance:
    :inherited-members:
